<!--
SPDX-FileCopyrightText: 2023 The eminus developers
SPDX-License-Identifier: Apache-2.0
-->
# pbe

Files for the Goedecker, Teter, Hutter (GTH) pseudopotential calculation. Theor. Chem. Acc. 114, 145.

To be used with the PBE exchange-correlation functional.

Files taken from: https://github.com/cp2k/cp2k-data

The files can be updated with (only for maintaining purposes)

```terminal
python __init__.py
```
